from distutils.core import setup
setup(
  name = 'passwordsgo',         
  packages = ['PyPass'],   
  version = '0.2',    
  license='GPLv3',        
  description = 'store passwords safely with ease.', 
  long_description='A simple Experimental Password Management tool done as student Project.',
  author = 'Anish M',                  
  author_email = 'aneesh25861@gmail.com',     
  url = 'https://github.com/anish-m-code/PyPass',  
  download_url = 'https://github.com/Anish-M-code/PyPass/archive/v3.02.tar.gz',    
  keywords = ['Student Project', 'cryptography','Password Manager'],  
  classifiers=[
    'Development Status :: 3 - Alpha',      
    'Intended Audience :: Developers',      
    'Topic :: Software Development',
    'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',   
    'Programming Language :: Python :: 3',      
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

